@@ -30,12 +30,21 @@ class asyauthSecret(enum.Enum):
 	RC4 = 'RC4'
 	AES = 'AES'
 	CCACHE = 'CCACHE'
+	CCACHEHEX = 'CCACHEHEX'
+	CCACHEB64 = 'CCACHEB64'
 	KEYTAB = 'KEYTAB'
+	KEYTABHEX = 'KEYTABHEX'
+	KEYTABB64 = 'KEYTABB64'
 	PFX = 'PFX'
 	PFXSTR = 'PFXSTR'
 	PEM = 'PEM'
 	CERTSTORE = 'CERTSTORE'
 	KIRBI = 'KIRBI'
+	KIRBIHEX = 'KIRBIHEX'
+	KIRBIB64 = 'KIRBIB64'
 	DES = 'DES'
 	TDES = 'TDES'
-	DES3 = 'DES3'
\ No newline at end of file
+	DES3 = 'DES3'
+	SSHPRIVKEY = 'SSHPRIVKEY'
+	SSHPRIVKEYSTR = 'SSHPRIVKEYSTR'
+	SSHPRIVKEYB64 = 'SSHPRIVKEYB64'
\ No newline at end of file
